using System;
using System.Collections;
using Server;
using Server.Engines.BulkOrders;

namespace Server.Mobiles
{
	public class Bowyer : BaseVendor
	{
		private ArrayList m_SBInfos = new ArrayList();
		protected override ArrayList SBInfos{ get { return m_SBInfos; } }

		[Constructable]
		public Bowyer() : base( "the bowyer" )
		{
			SetSkill( SkillName.Archery, 60.0, 83.0 );
			SetSkill( SkillName.Fletching, 90.0, 100.0 );
		}

		public override void InitSBInfo()
		{
			//m_SBInfos.Add( new SBRingmailArmor() );
			//m_SBInfos.Add( new SBStuddedArmor() );
			//m_SBInfos.Add( new SBLeatherArmor() );
			m_SBInfos.Add( new SBRangedWeapon() );
			m_SBInfos.Add( new SBBowyer() );
		}

		public override VendorShoeType ShoeType
		{
			get{ return Utility.RandomBool() ? VendorShoeType.Boots : VendorShoeType.ThighBoots; }
		}

		public override int GetShoeHue()
		{
			return 0;
		}

		public override void InitOutfit()
		{
			base.InitOutfit();

			AddItem( new Server.Items.Bow() );
			AddItem( new Server.Items.LeatherGorget() );
		}

                #region Bulk Orders
		public override Item CreateBulkOrder( Mobile from, bool fromContextMenu )
		{
			PlayerMobile pm = from as PlayerMobile;

			if ( pm != null && pm.NextFletcherBulkOrder == TimeSpan.Zero && (fromContextMenu || 0.2 > Utility.RandomDouble()) )
			{
				double theirSkill = pm.Skills[SkillName.Fletching].Base;

				if ( theirSkill >= 70.1 )
					pm.NextFletcherBulkOrder = TimeSpan.FromHours( 0.015 );
				else if ( theirSkill >= 50.1 )
					pm.NextFletcherBulkOrder = TimeSpan.FromHours( 0.015 );
				else
					pm.NextFletcherBulkOrder = TimeSpan.FromHours( 0.015 );

				if ( theirSkill >= 50.1 && ((theirSkill - 40.0) / 300.0) > Utility.RandomDouble() )
					return new LargeFletcherBOD();

				return SmallFletcherBOD.CreateRandomFor( from );
			}

			return null;
		}

		public override bool IsValidBulkOrder( Item item )
		{
			return ( item is SmallFletcherBOD || item is LargeFletcherBOD );
		}

		public override bool SupportsBulkOrders( Mobile from )
		{
			return ( from is PlayerMobile && from.Skills[SkillName.Fletching].Base > 0 );
		}

		public override TimeSpan GetNextBulkOrder( Mobile from )
		{
			if ( from is PlayerMobile )
				return ((PlayerMobile)from).NextFletcherBulkOrder;

			return TimeSpan.Zero;
		}
		#endregion

		public Bowyer( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
		}
	}
}
	